# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmLLMKnowledgeEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster': 'OrmKernelCluster',
        'created_by': 'OrmUser',
        'embedding_model': 'OrmLLMModelConnection',
        'llm_documents': 'list[OrmLLMDocument]',
        'llm_knowledge_jobs': 'list[OrmLLMKnowledgeJob]',
        'llm_knowledge_llm_user_group': 'list[OrmLLMKnowledgeLLMUserGroup]',
        'organization': 'OrmOrganization',
        'resource_spec_preset': 'OrmKernelResourceSpec',
        'vectordb_connection': 'OrmLLMVectorDBConnection'
    }

    attribute_map = {
        'cluster': 'cluster',
        'created_by': 'created_by',
        'embedding_model': 'embedding_model',
        'llm_documents': 'llm_documents',
        'llm_knowledge_jobs': 'llm_knowledge_jobs',
        'llm_knowledge_llm_user_group': 'llm_knowledge_llm_user_group',
        'organization': 'organization',
        'resource_spec_preset': 'resource_spec_preset',
        'vectordb_connection': 'vectordb_connection'
    }

    def __init__(self, cluster=None, created_by=None, embedding_model=None, llm_documents=None, llm_knowledge_jobs=None, llm_knowledge_llm_user_group=None, organization=None, resource_spec_preset=None, vectordb_connection=None, local_vars_configuration=None):  # noqa: E501
        """OrmLLMKnowledgeEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster = None
        self._created_by = None
        self._embedding_model = None
        self._llm_documents = None
        self._llm_knowledge_jobs = None
        self._llm_knowledge_llm_user_group = None
        self._organization = None
        self._resource_spec_preset = None
        self._vectordb_connection = None
        self.discriminator = None

        if cluster is not None:
            self.cluster = cluster
        if created_by is not None:
            self.created_by = created_by
        if embedding_model is not None:
            self.embedding_model = embedding_model
        if llm_documents is not None:
            self.llm_documents = llm_documents
        if llm_knowledge_jobs is not None:
            self.llm_knowledge_jobs = llm_knowledge_jobs
        if llm_knowledge_llm_user_group is not None:
            self.llm_knowledge_llm_user_group = llm_knowledge_llm_user_group
        if organization is not None:
            self.organization = organization
        if resource_spec_preset is not None:
            self.resource_spec_preset = resource_spec_preset
        if vectordb_connection is not None:
            self.vectordb_connection = vectordb_connection

    @property
    def cluster(self):
        """Gets the cluster of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The cluster of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmKernelCluster
        """
        return self._cluster

    @cluster.setter
    def cluster(self, cluster):
        """Sets the cluster of this OrmLLMKnowledgeEdges.


        :param cluster: The cluster of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type cluster: OrmKernelCluster
        """

        self._cluster = cluster

    @property
    def created_by(self):
        """Gets the created_by of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The created_by of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this OrmLLMKnowledgeEdges.


        :param created_by: The created_by of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type created_by: OrmUser
        """

        self._created_by = created_by

    @property
    def embedding_model(self):
        """Gets the embedding_model of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The embedding_model of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmLLMModelConnection
        """
        return self._embedding_model

    @embedding_model.setter
    def embedding_model(self, embedding_model):
        """Sets the embedding_model of this OrmLLMKnowledgeEdges.


        :param embedding_model: The embedding_model of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type embedding_model: OrmLLMModelConnection
        """

        self._embedding_model = embedding_model

    @property
    def llm_documents(self):
        """Gets the llm_documents of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The llm_documents of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: list[OrmLLMDocument]
        """
        return self._llm_documents

    @llm_documents.setter
    def llm_documents(self, llm_documents):
        """Sets the llm_documents of this OrmLLMKnowledgeEdges.


        :param llm_documents: The llm_documents of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type llm_documents: list[OrmLLMDocument]
        """

        self._llm_documents = llm_documents

    @property
    def llm_knowledge_jobs(self):
        """Gets the llm_knowledge_jobs of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The llm_knowledge_jobs of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: list[OrmLLMKnowledgeJob]
        """
        return self._llm_knowledge_jobs

    @llm_knowledge_jobs.setter
    def llm_knowledge_jobs(self, llm_knowledge_jobs):
        """Sets the llm_knowledge_jobs of this OrmLLMKnowledgeEdges.


        :param llm_knowledge_jobs: The llm_knowledge_jobs of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type llm_knowledge_jobs: list[OrmLLMKnowledgeJob]
        """

        self._llm_knowledge_jobs = llm_knowledge_jobs

    @property
    def llm_knowledge_llm_user_group(self):
        """Gets the llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: list[OrmLLMKnowledgeLLMUserGroup]
        """
        return self._llm_knowledge_llm_user_group

    @llm_knowledge_llm_user_group.setter
    def llm_knowledge_llm_user_group(self, llm_knowledge_llm_user_group):
        """Sets the llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.


        :param llm_knowledge_llm_user_group: The llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type llm_knowledge_llm_user_group: list[OrmLLMKnowledgeLLMUserGroup]
        """

        self._llm_knowledge_llm_user_group = llm_knowledge_llm_user_group

    @property
    def organization(self):
        """Gets the organization of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The organization of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmLLMKnowledgeEdges.


        :param organization: The organization of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def resource_spec_preset(self):
        """Gets the resource_spec_preset of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The resource_spec_preset of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmKernelResourceSpec
        """
        return self._resource_spec_preset

    @resource_spec_preset.setter
    def resource_spec_preset(self, resource_spec_preset):
        """Sets the resource_spec_preset of this OrmLLMKnowledgeEdges.


        :param resource_spec_preset: The resource_spec_preset of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type resource_spec_preset: OrmKernelResourceSpec
        """

        self._resource_spec_preset = resource_spec_preset

    @property
    def vectordb_connection(self):
        """Gets the vectordb_connection of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The vectordb_connection of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmLLMVectorDBConnection
        """
        return self._vectordb_connection

    @vectordb_connection.setter
    def vectordb_connection(self, vectordb_connection):
        """Sets the vectordb_connection of this OrmLLMKnowledgeEdges.


        :param vectordb_connection: The vectordb_connection of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type vectordb_connection: OrmLLMVectorDBConnection
        """

        self._vectordb_connection = vectordb_connection

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmLLMKnowledgeEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmLLMKnowledgeEdges):
            return True

        return self.to_dict() != other.to_dict()
