# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmClusterCustomEndpointConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'certificate_secret_name': 'str',
        'cluster_agent_namespace': 'str',
        'nodeport_config': 'OrmNodePortConfig',
        'subdomain_config': 'OrmSubdomainConfig',
        'tls_enabled': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'certificate_secret_name': 'certificate_secret_name',
        'cluster_agent_namespace': 'cluster_agent_namespace',
        'nodeport_config': 'nodeport_config',
        'subdomain_config': 'subdomain_config',
        'tls_enabled': 'tls_enabled',
        'type': 'type'
    }

    def __init__(self, certificate_secret_name=None, cluster_agent_namespace=None, nodeport_config=None, subdomain_config=None, tls_enabled=None, type=None, local_vars_configuration=None):  # noqa: E501
        """OrmClusterCustomEndpointConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._certificate_secret_name = None
        self._cluster_agent_namespace = None
        self._nodeport_config = None
        self._subdomain_config = None
        self._tls_enabled = None
        self._type = None
        self.discriminator = None

        self.certificate_secret_name = certificate_secret_name
        if cluster_agent_namespace is not None:
            self.cluster_agent_namespace = cluster_agent_namespace
        if nodeport_config is not None:
            self.nodeport_config = nodeport_config
        if subdomain_config is not None:
            self.subdomain_config = subdomain_config
        if tls_enabled is not None:
            self.tls_enabled = tls_enabled
        if type is not None:
            self.type = type

    @property
    def certificate_secret_name(self):
        """Gets the certificate_secret_name of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The certificate_secret_name of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: str
        """
        return self._certificate_secret_name

    @certificate_secret_name.setter
    def certificate_secret_name(self, certificate_secret_name):
        """Sets the certificate_secret_name of this OrmClusterCustomEndpointConfig.


        :param certificate_secret_name: The certificate_secret_name of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type certificate_secret_name: str
        """

        self._certificate_secret_name = certificate_secret_name

    @property
    def cluster_agent_namespace(self):
        """Gets the cluster_agent_namespace of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The cluster_agent_namespace of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: str
        """
        return self._cluster_agent_namespace

    @cluster_agent_namespace.setter
    def cluster_agent_namespace(self, cluster_agent_namespace):
        """Sets the cluster_agent_namespace of this OrmClusterCustomEndpointConfig.


        :param cluster_agent_namespace: The cluster_agent_namespace of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type cluster_agent_namespace: str
        """

        self._cluster_agent_namespace = cluster_agent_namespace

    @property
    def nodeport_config(self):
        """Gets the nodeport_config of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The nodeport_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: OrmNodePortConfig
        """
        return self._nodeport_config

    @nodeport_config.setter
    def nodeport_config(self, nodeport_config):
        """Sets the nodeport_config of this OrmClusterCustomEndpointConfig.


        :param nodeport_config: The nodeport_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type nodeport_config: OrmNodePortConfig
        """

        self._nodeport_config = nodeport_config

    @property
    def subdomain_config(self):
        """Gets the subdomain_config of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The subdomain_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: OrmSubdomainConfig
        """
        return self._subdomain_config

    @subdomain_config.setter
    def subdomain_config(self, subdomain_config):
        """Sets the subdomain_config of this OrmClusterCustomEndpointConfig.


        :param subdomain_config: The subdomain_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type subdomain_config: OrmSubdomainConfig
        """

        self._subdomain_config = subdomain_config

    @property
    def tls_enabled(self):
        """Gets the tls_enabled of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The tls_enabled of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: bool
        """
        return self._tls_enabled

    @tls_enabled.setter
    def tls_enabled(self, tls_enabled):
        """Sets the tls_enabled of this OrmClusterCustomEndpointConfig.


        :param tls_enabled: The tls_enabled of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type tls_enabled: bool
        """

        self._tls_enabled = tls_enabled

    @property
    def type(self):
        """Gets the type of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The type of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmClusterCustomEndpointConfig.


        :param type: The type of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type type: str
        """

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmClusterCustomEndpointConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmClusterCustomEndpointConfig):
            return True

        return self.to_dict() != other.to_dict()
