# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmProjectDashboardExperimentFieldConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'dashboard_id': 'int',
        'display_name': 'str',
        'edges': 'OrmProjectDashboardExperimentFieldConfigEdges',
        'experiment_field_id': 'int',
        'id': 'int',
        'is_filterable': 'bool',
        'is_hidden': 'bool',
        'is_pinned': 'bool',
        'is_sortable': 'bool',
        'order': 'int',
        'updated_dt': 'datetime',
        'width': 'int'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'dashboard_id': 'dashboard_id',
        'display_name': 'display_name',
        'edges': 'edges',
        'experiment_field_id': 'experiment_field_id',
        'id': 'id',
        'is_filterable': 'is_filterable',
        'is_hidden': 'is_hidden',
        'is_pinned': 'is_pinned',
        'is_sortable': 'is_sortable',
        'order': 'order',
        'updated_dt': 'updated_dt',
        'width': 'width'
    }

    def __init__(self, created_dt=None, dashboard_id=None, display_name=None, edges=None, experiment_field_id=None, id=None, is_filterable=None, is_hidden=None, is_pinned=None, is_sortable=None, order=None, updated_dt=None, width=None, local_vars_configuration=None):  # noqa: E501
        """OrmProjectDashboardExperimentFieldConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._dashboard_id = None
        self._display_name = None
        self._edges = None
        self._experiment_field_id = None
        self._id = None
        self._is_filterable = None
        self._is_hidden = None
        self._is_pinned = None
        self._is_sortable = None
        self._order = None
        self._updated_dt = None
        self._width = None
        self.discriminator = None

        if created_dt is not None:
            self.created_dt = created_dt
        if dashboard_id is not None:
            self.dashboard_id = dashboard_id
        if display_name is not None:
            self.display_name = display_name
        if edges is not None:
            self.edges = edges
        if experiment_field_id is not None:
            self.experiment_field_id = experiment_field_id
        if id is not None:
            self.id = id
        if is_filterable is not None:
            self.is_filterable = is_filterable
        if is_hidden is not None:
            self.is_hidden = is_hidden
        if is_pinned is not None:
            self.is_pinned = is_pinned
        if is_sortable is not None:
            self.is_sortable = is_sortable
        self.order = order
        if updated_dt is not None:
            self.updated_dt = updated_dt
        self.width = width

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The created_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmProjectDashboardExperimentFieldConfig.


        :param created_dt: The created_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def dashboard_id(self):
        """Gets the dashboard_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The dashboard_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, dashboard_id):
        """Sets the dashboard_id of this OrmProjectDashboardExperimentFieldConfig.


        :param dashboard_id: The dashboard_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type dashboard_id: int
        """

        self._dashboard_id = dashboard_id

    @property
    def display_name(self):
        """Gets the display_name of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The display_name of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this OrmProjectDashboardExperimentFieldConfig.


        :param display_name: The display_name of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type display_name: str
        """

        self._display_name = display_name

    @property
    def edges(self):
        """Gets the edges of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The edges of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: OrmProjectDashboardExperimentFieldConfigEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmProjectDashboardExperimentFieldConfig.


        :param edges: The edges of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type edges: OrmProjectDashboardExperimentFieldConfigEdges
        """

        self._edges = edges

    @property
    def experiment_field_id(self):
        """Gets the experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._experiment_field_id

    @experiment_field_id.setter
    def experiment_field_id(self, experiment_field_id):
        """Sets the experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.


        :param experiment_field_id: The experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type experiment_field_id: int
        """

        self._experiment_field_id = experiment_field_id

    @property
    def id(self):
        """Gets the id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmProjectDashboardExperimentFieldConfig.


        :param id: The id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def is_filterable(self):
        """Gets the is_filterable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_filterable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_filterable

    @is_filterable.setter
    def is_filterable(self, is_filterable):
        """Sets the is_filterable of this OrmProjectDashboardExperimentFieldConfig.


        :param is_filterable: The is_filterable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_filterable: bool
        """

        self._is_filterable = is_filterable

    @property
    def is_hidden(self):
        """Gets the is_hidden of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_hidden of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this OrmProjectDashboardExperimentFieldConfig.


        :param is_hidden: The is_hidden of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_hidden: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_pinned(self):
        """Gets the is_pinned of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_pinned of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_pinned

    @is_pinned.setter
    def is_pinned(self, is_pinned):
        """Sets the is_pinned of this OrmProjectDashboardExperimentFieldConfig.


        :param is_pinned: The is_pinned of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_pinned: bool
        """

        self._is_pinned = is_pinned

    @property
    def is_sortable(self):
        """Gets the is_sortable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_sortable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_sortable

    @is_sortable.setter
    def is_sortable(self, is_sortable):
        """Sets the is_sortable of this OrmProjectDashboardExperimentFieldConfig.


        :param is_sortable: The is_sortable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_sortable: bool
        """

        self._is_sortable = is_sortable

    @property
    def order(self):
        """Gets the order of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The order of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this OrmProjectDashboardExperimentFieldConfig.


        :param order: The order of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type order: int
        """

        self._order = order

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The updated_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmProjectDashboardExperimentFieldConfig.


        :param updated_dt: The updated_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def width(self):
        """Gets the width of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The width of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this OrmProjectDashboardExperimentFieldConfig.


        :param width: The width of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type width: int
        """

        self._width = width

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmProjectDashboardExperimentFieldConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmProjectDashboardExperimentFieldConfig):
            return True

        return self.to_dict() != other.to_dict()
